==> ttcomment-0.0.1.tar.gz: lib/comment_widget/comment_widagets.dart <==
/*
 * @Description: 
 * @Version: 2.0
 * @Autor: ftt
 * @Date: 2022-04-25 10:51:40
 * @LastEditors: ftt
 * @LastEditTime: 2022-05-06 10:09:11
 */

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../ttcomment.dart';

/*
 * @description: 创建通用 item 带> 带下划线 带 点击事件
 * @param {
 * title 左边文字
 * messge 右边文字
 * isshowline 是否显示细线,默认false
 * ontap item 点击事件回调
 * mainAxisAlignment title 和 messge  横轴显示位置
 * isshownext 是否显示 > 默认不显示
 * }
 * @return {*}
 */

// ignore: non_constant_identifier_names
Widget CreateNormalItemWidget({
  required String title,
  String? messge,
  bool? isshowline = false,
  Function(int)? ontap,
  MainAxisAlignment? mainAxisAlignment = MainAxisAlignment.spaceBetween,
  bool? isshownext = false,
  int type = 0,
  double height = 50,
  EdgeInsetsGeometry? padding = const EdgeInsets.only(left: 20,),
  bool? istap = false,
  int? index = 0,
  Color? arrowrightColor = CommentColorS.col666666,
  Widget? leftwidget,
  Widget? rightwidget,
  Widget? arrowrightwidget,
  Widget? linewidget,
}) {
  return InkWell(
    onTap: () {
      if (ontap != null && istap!) {
        ontap(index!);
      }
    },
    child: Container(
      height: height,
      padding: padding,
      color: Colors.white,
      child: Column(
        children: [
          SizedBox(
            height: height - 0.5,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Expanded(
                  child: Row(
                    mainAxisAlignment: mainAxisAlignment!,
                    children: [
                      leftwidget ??
                          Text(
                            title,
                            style: TextStyleMacor.fontMedium(
                              14.sp,
                              type == 0
                                  ? CommentColorS.col222222
                                  : CommentColorS.col666666,
                            ),
                          ),
                      rightwidget ??
                          Text(
                            messge ?? "",
                            style: TextStyleMacor.fontMedium(
                              14.sp,
                              CommentColorS.col222222,
                            ),
                          ),
                    ],
                  ),
                ),
                isshownext!
                    ? arrowrightwidget ??
                        Icon(
                          Icons.chevron_right,
                          size: 20.w,
                          color: arrowrightColor,
                        )
                    : Container(),
              ],
            ),
          ),
          isshowline!
              ? linewidget ??
                  CommentTools.configlineSpace(
                    color: CommentColorS.colebebeb,
                  )
              : Container()
        ],
      ),
    ),
  );
}

==> ttcomment-0.0.3.tar.gz: lib/comment_widget/comment_widagets.dart <==
/*
 * @Description: 
 * @Version: 2.0
 * @Autor: ftt
 * @Date: 2022-04-25 10:51:40
 * @LastEditors: TT
 * @LastEditTime: 2022-06-22 16:25:41
 */

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../ttcomment.dart';

/*
 * @description: 创建通用 item 带> 带下划线 带 点击事件
 * @param {
 * title 左边文字
 * messge 右边文字
 * isshowline 是否显示细线,默认false
 * ontap item 点击事件回调
 * mainAxisAlignment title 和 messge  横轴显示位置
 * isshownext 是否显示 > 默认不显示
 * }
 * @return {*}
 */

// ignore: non_constant_identifier_names
Widget CreateNormalItemWidget({
  String? title,
  String? messge,
  bool? isshowline = false,
  Function(int)? ontap,
  MainAxisAlignment? mainAxisAlignment = MainAxisAlignment.spaceBetween,
  bool? isshownext = false,
  int type = 0,
  double height = 50,
  EdgeInsetsGeometry? padding = const EdgeInsets.only(
    left: 20,
  ),
  bool? istap = false,
  int? index = 0,
  Color? arrowrightColor = CommentColorS.col666666,
  Widget? leftwidget,
  Widget? rightwidget,
  Widget? arrowrightwidget,
  Widget? linewidget,
  Color? backgroundColor,
}) {
  return InkWell(
    onTap: () {
      if (ontap != null && istap!) {
        ontap(index!);
      }
    },
    child: Container(
      height: height,
      padding: padding,
      color: backgroundColor ?? Colors.white,
      child: Column(
        children: [
          SizedBox(
            height: height - 0.5,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Expanded(
                  child: Row(
                    mainAxisAlignment: mainAxisAlignment!,
                    children: [
                      leftwidget ??
                          Text(
                            title ?? "",
                            style: TextStyleMacor.fontMedium(
                              14.sp,
                              type == 0
                                  ? CommentColorS.col222222
                                  : CommentColorS.col666666,
                            ),
                          ),
                      rightwidget ??
                          Text(
                            messge ?? "",
                            style: TextStyleMacor.fontMedium(
                              14.sp,
                              CommentColorS.col222222,
                            ),
                          ),
                    ],
                  ),
                ),
                isshownext!
                    ? arrowrightwidget ??
                        Icon(
                          Icons.chevron_right,
                          size: 20.w,
                          color: arrowrightColor,
                        )
                    : Container(),
              ],
            ),
          ),
          isshowline!
              ? linewidget ??
                  CommentTools.configlineSpace(
                    color: CommentColorS.colebebeb,
                  )
              : Container()
        ],
      ),
    ),
  );
}
